@@ -21,7 +21,7 @@ class ArrayType(Enum):
     @classmethod
     def from_probe_count(cls, probe_count):
         """Determines array type using number of probes counted in raw idat file. Returns array string."""
-        if probe_count == 1055583:
+        if probe_count == 1055583 or probe_count == 868578:
             return cls.ILLUMINA_EPIC_PLUS
 
         if 622000 <= probe_count <= 623000:
@@ -38,7 +38,7 @@ class ArrayType(Enum):
             #B1 V1 274390 actual probes == rows in manifest
             #B3 V2 299344 actual probes == rows in manifest file; 361821 count from idat
 
-        if 56000 <= probe_count <= 1050000:
+        if 56000 <= probe_count <= 1100000:
             LOGGER.warning(f'Probe count ({probe_count}) falls outside of normal range. Setting to newest array type: EPIC')
             return cls.ILLUMINA_EPIC
 
@@ -58,7 +58,10 @@ class ArrayType(Enum):
             # test: added +1 because mouse controls were short by one. and this fixed it. prob
             # need to test them ALL and add +1 header in manifest.py code.
             #B1 V2 = 273757, # test: list where all control probes start
-            ArrayType.ILLUMINA_MOUSE: 298710, #B3 V2 row number for first control probe (after [Controls],,,,,,)
+            #ArrayType.ILLUMINA_MOUSE: 298710, #B3 V2 row number for first control probe (after [Controls],,,,,,header)
+            ArrayType.ILLUMINA_MOUSE: 297414,
+            #287054 #287054 is first control row; no header row
+            #297415 # row number for first control probe (after header [Controls],,,, ) with row count starting at zero.
         }
         return probe_counts.get(self)
 
@@ -69,7 +72,7 @@ class ArrayType(Enum):
             ArrayType.ILLUMINA_450K: 850,
             ArrayType.ILLUMINA_EPIC: 635,
             ArrayType.ILLUMINA_EPIC_PLUS: 635,
-            ArrayType.ILLUMINA_MOUSE: 635, # starts at line 298710 in manifest; V1 268833
+            ArrayType.ILLUMINA_MOUSE: 1966,
         }
         return probe_counts.get(self)
 
@@ -80,7 +83,7 @@ class ArrayType(Enum):
             ArrayType.ILLUMINA_450K: 65,
             ArrayType.ILLUMINA_EPIC: 59,
             ArrayType.ILLUMINA_EPIC_PLUS: 120,
-            ArrayType.ILLUMINA_MOUSE: 536, #was at end of file, now before control (testing)
+            ArrayType.ILLUMINA_MOUSE: 1353, #in v2: 536, #was at end of file, now before control (testing)
         }
         return probe_counts.get(self)
 
