@@ -4,7 +4,7 @@ from enum import Enum, unique
 
 @unique
 class ControlType(Enum):
-    STAINING = 'STAINING'
+    STAINING = 'STAINING' # NOT FOUND IN MOUSE MANIFEST
     EXTENSION = 'EXTENSION'
     HYBRIDIZATION = 'HYBRIDIZATION'
     TARGET_REMOVAL = 'TARGET REMOVAL'
@@ -12,7 +12,7 @@ class ControlType(Enum):
     BISULFITE_CONVERSION_II = 'BISULFITE CONVERSION II'
     SPECIFICITY_I = 'SPECIFICITY I'
     SPECIFICITY_II = 'SPECIFICITY II'
-    NON_POLYMORPHIC = 'NON - POLYMORPHIC'
+    NON_POLYMORPHIC = 'NON-POLYMORPHIC' # changed from 'NON - POLYMORPHIC' on 2020-12-01 to match manifests
     NEGATIVE = 'NEGATIVE'
     RESTORATION = 'RESTORATION'
     NORM_A = 'NORM_A'
