@@ -27,9 +27,14 @@ class MethylationDataset():
         manifest {Manifest} -- The Manifest for the correlated RawDataset's array type.
         probe_subsets {list(ProbeSubset)} -- Collection of ProbeSubsets that correspond to the probe type
         (methylated or unmethylated).
+
+    note: self.methylated.data_frame 'bg_corrected' and 'noob' values will be same under preprocess_sesame_noob,
+    but different under minfi/legacy pre-v1.4.0 results. And this 'noob' will not match SampleDataContainer.dataframe
+    because dye-bias correction happens later in processing.
     """
     __bg_corrected = False
     __preprocessed = False # AKA NOOB CORRECTED
+    __dye_bias_corrected = False
 
     def __init__(self, raw_dataset, manifest, probe_subsets):
         #LOGGER.info('Preprocessing methylation dataset: %s', raw_dataset.sample)
@@ -64,24 +69,25 @@ class MethylationDataset():
         """ convenience method that feeds in a pre-defined list of UNmethylated Snp locii probes """
         return cls(raw_dataset, manifest, UNMETHYLATED_SNP_PROBES)
 
-    #@classmethod
-    #def mouse_methylated(cls, raw_dataset, manifest):
-    #    """ convenience method that feeds in a pre-defined list of methylated MOUSE specific probes """
-    #    return cls(raw_dataset, manifest, METHYLATED_MOUSE_PROBES)
-    #
-    #@classmethod
-    #def mouse_unmethylated(cls, raw_dataset, manifest):
-    #    """ convenience method that feeds in a pre-defined list of UNmethylated MOUSE specific probes """
-    #    return cls(raw_dataset, manifest, UNMETHYLATED_MOUSE_PROBES)
-
     def build_data_frame(self):
         return pd.concat(self.data_frames.values())
 
     def _get_subset_means(self, manifest, probe_subset):
-        channel_means = self.raw_dataset.get_channel_means(probe_subset.data_channel)
-        channel_means = channel_means.assign(Channel=probe_subset.data_channel.value)
+        """ nearly the same as raw_data.get_subset_means, but this index is IlmnID and raw_data index is illumina_id."""
+        channel_means_df = self.raw_dataset.get_channel_means(probe_subset.data_channel)
+        channel_means_df = channel_means_df.assign(Channel=probe_subset.data_channel.value)
 
-        probe_details = probe_subset.get_probe_details(manifest)
+        #probe_details = probe_subset.get_probe_details(manifest)
+        probe_details = manifest.get_probe_details(probe_subset.probe_type, probe_subset.probe_channel)
+
+        # check here for probes that are missing data in manifest, and drop them if they are (better to be imperfect with warnings)
+        if probe_details[probe_subset.probe_address.header_name].isna().sum() > 0:
+            print('These probes are probably incorrect in your manifest; processing cannot continue.')
+            print( probe_details.loc[ probe_details[probe_subset.probe_address.header_name].isna() ].index )
+            pre_shape = probe_details.shape
+            probe_details = probe_details.drop( probe_details[ probe_details[probe_subset.probe_address.header_name].isna() ].index )
+            print(f"{pre_shape[0] - probe_details.shape[0]} removed; {probe_details[probe_subset.probe_address.header_name].isna().sum()} nan remaining; but downstream steps will not work.")
+            # this still won't fix it, because OOB also does some filtering.
 
         # check here for probes that are missing data in manifest, and drop them if they are (better to be imperfect with warnings)
         if probe_details[probe_subset.probe_address.header_name].isna().sum() > 0:
@@ -93,9 +99,9 @@ class MethylationDataset():
             # this still won't fix it, because OOB also does some filtering.
 
         return probe_details.merge(
-            channel_means,
+            channel_means_df,
             how='inner',
-            left_on=probe_subset.probe_address.header_name,
+            left_on=probe_subset.probe_address.header_name, # AddressA_ID or AddressB_ID
             right_index=True,
             suffixes=(False, False),
         )
@@ -116,10 +122,10 @@ class MethylationDataset():
 
     def _set_subset_bg_corrected(self, probe_subset, corrected_values):
         original = self.data_frames[probe_subset]
-        column = probe_subset.column_name
+        column = probe_subset.column_name # AddressA_ID or AddressB_ID
+
+        filtered_corrected = corrected_values.loc[original[column]] # adds the 'bg_corrected' column
 
-        filtered_corrected = corrected_values.loc[original[column]]
-        
         updated = original.merge(
             filtered_corrected[['bg_corrected']],
             how='inner',
@@ -137,6 +143,7 @@ class MethylationDataset():
             else:
                 data_frame = data_frame.assign(noob=data_frame['bg_corrected'])
 
+            #data_frame = data_frame.drop('bg_corrected', axis='columns') # no longer needed
             self.data_frames[probe_subset] = data_frame
 
         self.data_frame = self.build_data_frame()
