@@ -1,18 +1,15 @@
-from .pipeline import SampleDataContainer, get_manifest, run_pipeline
+from .pipeline import SampleDataContainer, get_manifest, run_pipeline, make_pipeline
 from .preprocess import preprocess_noob
-from .raw_dataset import RawDataset, get_raw_datasets, get_array_type
 from .postprocess import consolidate_values_for_sheet
 from .read_geo_processed import read_geo, detect_header_pattern
 
 __all__ = [
-    'RawDataset',
     'SampleDataContainer',
     'get_manifest',
-    'get_raw_datasets',
     'preprocess_noob',
     'run_pipeline',
+    'make_pipeline,'
     'consolidate_values_for_sheet',
-    'get_array_type',
     'read_geo',
     'detect_header_pattern',
 ]
